@@ -39,12 +39,12 @@ def compile_stst_func_str(evars, par, stst, init):
     stst_str = '; '.join([f'{v} = {stst[v]}' for v in stst])
 
     # compile the final function string
-    func_pre_stst_str = f"""def func_pre_stst(Y):
-        \n ({"".join(v + ", " for v in init)}) = Y
+    func_pre_stst_str = f"""def func_pre_stst(INTERNAL_init):
+        \n ({"".join(v + ", " for v in init)}) = INTERNAL_init
         \n {stst_str}
-        \n X = ({"".join(v + ", " for v in evars)})
-        \n par = ({"".join(p + ", " for p in par)})
-        \n return jnp.array(X), jnp.array(par)"""
+        \n INTERNAL_vars = ({"".join(v + ", " for v in evars)})
+        \n INTERNAL_par = ({"".join(p + ", " for p in par)})
+        \n return jnp.array(INTERNAL_vars), jnp.array(INTERNAL_par)"""
 
     return func_pre_stst_str
 
